@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
-# Copyright (c) 2008-2019 pyglet contributors
+# Copyright (c) 2008-2021 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -159,7 +159,7 @@ class DS3DLISTENER(ctypes.Structure):
     ]
 LPDS3DLISTENER = ctypes.POINTER(DS3DLISTENER)
 
-class IDirectSoundBuffer(com.IUnknown):
+class IDirectSoundBuffer(com.pIUnknown):
     _methods_ = [
         ('GetCaps',
          com.STDMETHOD(LPDSBCAPS)),
@@ -205,7 +205,7 @@ class IDirectSoundBuffer(com.IUnknown):
 IID_IDirectSound3DListener = com.GUID(
     0x279AFA84, 0x4981, 0x11CE, 0xA5, 0x21, 0x00, 0x20, 0xAF, 0x0B, 0xE5, 0x60)
 
-class IDirectSound3DListener(com.IUnknown):
+class IDirectSound3DListener(com.pIUnknown):
     _methods_ = [
         ('GetAllParameters',
          com.STDMETHOD(LPDS3DLISTENER)),
@@ -243,7 +243,7 @@ class IDirectSound3DListener(com.IUnknown):
 IID_IDirectSound3DBuffer = com.GUID(
     0x279AFA86, 0x4981, 0x11CE, 0xA5, 0x21, 0x00, 0x20, 0xAF, 0x0B, 0xE5, 0x60)
 
-class IDirectSound3DBuffer(com.IUnknown):
+class IDirectSound3DBuffer(com.pIUnknown):
     _methods_ = [
         ('GetAllParameters',
          com.STDMETHOD(LPDS3DBUFFER)),
@@ -283,7 +283,7 @@ class IDirectSound3DBuffer(com.IUnknown):
          com.STDMETHOD(D3DVALUE, D3DVALUE, D3DVALUE, DWORD)),
     ]
 
-class IDirectSound(com.IUnknown):
+class IDirectSound(com.pIUnknown):
     _methods_ = [
         ('CreateSoundBuffer', 
          com.STDMETHOD(LPDSBUFFERDESC, 
