@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
-# Copyright (c) 2008-2020 pyglet contributors
+# Copyright (c) 2008-2021 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -152,6 +152,10 @@ class Win32Window(BaseWindow):
                 self.WINDOW_STYLE_TOOL: (WS_OVERLAPPED | WS_CAPTION | WS_SYSMENU,
                                          WS_EX_TOOLWINDOW),
                 self.WINDOW_STYLE_BORDERLESS: (WS_POPUP, 0),
+                self.WINDOW_STYLE_TRANSPARENT: (WS_OVERLAPPEDWINDOW,
+                                                WS_EX_LAYERED),
+                self.WINDOW_STYLE_OVERLAY: (WS_POPUP,
+                                            WS_EX_LAYERED | WS_EX_TRANSPARENT)
             }
             self._ws_style, self._ex_ws_style = styles[self._style]
 
@@ -268,6 +272,11 @@ class Win32Window(BaseWindow):
             x, y = self._client_to_window_pos(*factory.get_location())
             _user32.SetWindowPos(self._hwnd, hwnd_after,
                                  x, y, width, height, SWP_FRAMECHANGED)
+        elif self.style == 'transparent' or self.style == "overlay":
+            _user32.SetLayeredWindowAttributes(self._hwnd, 0, 254, LWA_ALPHA)
+            if self.style == "overlay":
+                _user32.SetWindowPos(self._hwnd, HWND_TOPMOST, 0,
+                                     0, width, height, SWP_NOMOVE | SWP_NOSIZE)
         else:
             _user32.SetWindowPos(self._hwnd, hwnd_after,
                                  0, 0, width, height, SWP_NOMOVE | SWP_FRAMECHANGED)
@@ -347,6 +356,16 @@ class Win32Window(BaseWindow):
     def switch_to(self):
         self.context.set_current()
 
+    def update_transparency(self):
+        region = _gdi32.CreateRectRgn(0, 0, -1, -1)
+        bb = DWM_BLURBEHIND()
+        bb.dwFlags = DWM_BB_ENABLE | DWM_BB_BLURREGION
+        bb.hRgnBlur = region
+        bb.fEnable = True
+
+        _dwmapi.DwmEnableBlurBehindWindow(self._hwnd, ctypes.byref(bb))
+        _gdi32.DeleteObject(region)
+
     def flip(self):
         self.draw_mouse_cursor()
 
@@ -355,6 +374,9 @@ class Win32Window(BaseWindow):
                 if self._interval:
                     _dwmapi.DwmFlush()
 
+        if self.style in ('overlay', 'transparent'):
+            self.update_transparency()
+
         self.context.flip()
 
     def set_location(self, x, y):
@@ -732,7 +754,7 @@ class Win32Window(BaseWindow):
 
     def _get_modifiers(self, key_lParam=0):
         modifiers = 0
-        if _user32.GetKeyState(VK_SHIFT) & 0xff00:
+        if self._keyboard_state[0x036] or self._keyboard_state[0x02A]:
             modifiers |= key.MOD_SHIFT
         if _user32.GetKeyState(VK_CONTROL) & 0xff00:
             modifiers |= key.MOD_CTRL
@@ -894,20 +916,21 @@ class Win32Window(BaseWindow):
   
             if inp.data.keyboard.MakeCode == 0x02A:  # LEFT_SHIFT
                 if not key_up and not self._keyboard_state[0x02A]:
-                    self.dispatch_event('on_key_press', key.LSHIFT, self._get_modifiers())
                     self._keyboard_state[0x02A] = True
+                    self.dispatch_event('on_key_press', key.LSHIFT, self._get_modifiers())
 
                 elif key_up and self._keyboard_state[0x02A]:
-                    self.dispatch_event('on_key_release', key.LSHIFT, self._get_modifiers())
                     self._keyboard_state[0x02A] = False
-            
-            elif inp.data.keyboard.MakeCode == 0x036: # RIGHT SHIFT
+                    self.dispatch_event('on_key_release', key.LSHIFT, self._get_modifiers())
+
+            elif inp.data.keyboard.MakeCode == 0x036:  # RIGHT SHIFT
                 if not key_up and not self._keyboard_state[0x036]:
-                    self.dispatch_event('on_key_press', key.RSHIFT, self._get_modifiers())
                     self._keyboard_state[0x036] = True
+                    self.dispatch_event('on_key_press', key.RSHIFT, self._get_modifiers())
+                    
                 elif key_up and self._keyboard_state[0x036]:
-                    self.dispatch_event('on_key_release', key.RSHIFT, self._get_modifiers())
-                    self._keyboard_state[0x036] = False            
+                    self._keyboard_state[0x036] = False
+                    self.dispatch_event('on_key_release', key.RSHIFT, self._get_modifiers())        
 
         return 0
 
@@ -1198,3 +1221,6 @@ class Win32Window(BaseWindow):
         # Reverse Y and call event.
         self.dispatch_event('on_file_drop', point.x, self._height - point.y, paths)
         return 0
+
+
+__all__ = ["Win32EventHandler", "Win32Window"]
